==> imm-apps-1.2.3.tar.gz: imm-apps-1.2.3/source/comment.py <==
comment = {
    "info-positon": {"how_when_offer": "请说明什么时候以及如何给TFW提供offer的"},
    "info-general": {
        "pt_employee_number": "每周工作时间少于30小时的为兼职",
    },
    "table-eraddress": {"mailing_address": "如果地址跟商业地址相同,请copy商业地址到这里"},
    "table-finance": {"year": "请填写上一年度,以及上上年度2年的财务信息"},
    "table-education": {"is_trade": "是否是技工类别？比如水电工"},
    "info-joboffer": {
        "atypical_schedule_explain": "请说明工作时间是如何安排的",
        "ot_after_hours_unit": "加班工资开始计算的单位,比如,每天超过8小时,那么该单位就是day；如果每周超过40小时,那么单位就是week",
        "ot_ratio": "加班工资是平时工资的倍数,比如1.5",
        "vacation_pay_percentage": "一般是4%,就填写0.04即可",
        "duties": "详细职责描述,可将excel行拉长。每条职责一行,一般在别的编辑器里面写好copy过来即可。",
        "specific_edu_requirement": "一句话描述对学历、教育程度、相关专业的要求",
    },
    "table-family": {"relationship": "请填写你的: 配偶,子女,母亲,父亲,兄弟姐妹,包括同母异父/同母异父的兄弟姐妹,"},
    "table-marriage": {
        "sp_canada_status": "请选择:Citizen (公民),Visitor(访问者,包括旅游,探亲,商务等),Student(学生),Worker(工人),Other(其他)"
    },
    "info-personal": {
        "last_name": "保持跟护照一致都拼音姓",
        "first_name": "保持跟护照一致都拼音名",
        "uci": "加拿大签证上Unified Client Identity号码",
        "ita_assessed": "这个是加拿大行业培训机构(Industry Training Authority)",
        "english_french": "English(英语) French(法语)Both(两个都会) Neither(两个都不会)",
        "primary_school_years": "如果没有,请填写0",
        "secondary_school_years": "如果没有,请填写0",
        "post_secondary_school_years": "如果没有,请填写0",
        "other_school_years": "如果没有,请填写0",
        "dependant_type": "Type A: 22岁以下的申请人, Type B:22岁以上,但一直在读书的。 Type C:22岁以上但有疾病需要依赖父母的",
    },
    "table-personid": {"expiry_date": "如果没有到期日期,请填写当前日期加上30年的日期"},
    "info-personalassess": {
        "work_experience_brief": "教育背景,工作经历,个人品质,语言能力 用于PNP的雇主信或者LMIA申请回答为什么申请人合格的问题。工作表现评价用于已经在该雇主那里工作的情况,在雇主推荐信中使用。"
    },
    "table-language": {
        "registration_number": "CELPIP叫registration number, IELTS叫 Test report form number, TEF叫Attestation n*, TCF叫N° de l'attestation",
        "pin": "仅仅当考试类型是CELPIP时需要",
        "date": "IELTS: administrator signature date,CELPIP: date of signing,TEF: date of session,TEF: date of session",
        "remark": "如果是实际考试成绩,选择Test Score,如果是估计成绩,选择Estimation",
    },
    "info-marriage": {
        "married_date": "若是single则不需要填写",
        "pre_sp_last_name": "只填写最近一段婚姻",
    },
    "table-phone": {"cellular": "优选手机作为通讯选择。如果有手机,只填写手机即可,如果没有,依次可以选择家庭电话,工作电话"},
    "table-address": {
        "residential_address": "如果地址跟邮件地址相同,请copy邮件地址到这里. 如果国家是加拿大,必须填写省份,而且用缩写,比如： AB, BC"
    },
    "info-trcasein": {
        "doc_number": "学签/工签/VR的右上角黑色的,一般为1个字母+9位数字",
        "original_purpose": "Business-商业,Tourism-旅游,study-学习,work-工作,family visit-家庭访问,或者other-其它",
        "original_other_reason": "若上一行填other则将原因补充在这里",
        "most_recent_entry_date": "如果这是第一次，此处不用填写",
        "most_recent_entry_place": "如果这是第一次，此处不用填写",
        "submission_date": "可以不用填写",
    },
    "info-visa": {
        "name1": "可填写学校或工作单位的名称和地址",
        "relationship1": "比如：如果是学校,就写my school.",
        "name2": "可填写学校或工作单位的名称和地址",
        "relationship2": "比如：如果是学校,就写my school.",
    },
    "info-vrincanada": {
        "name1": "可填写学校或工作单位的名称和地址",
        "relationship1": "比如：如果是学校,就写my school.",
        "name2": "可填写学校或工作单位的名称和地址",
        "relationship2": "比如：如果是学校,就写my school.",
        "other_explain": "如果访问目的填写的是Other,请说明。比如:accompany child studying in Canada",
    },
    "info-sp": {
        "dli": "中小学无需填写,大学参考学校给的offer",
        "tuition_cost": "填写一年的大致学费,加币,如49800",
        "room_cost": "填写一年的大致住宿费用,加币,如12000",
        "other_cost": "填写一年的大致生活等其它开支,加币,如12000",
        "other": "填写亲戚- relative,或奖学金-scholarship等",
    },
    "info-spincanada": {
        "dli": "中小学无需填写,大学参考学校给的offer",
        "tuition_cost": "填写一年的大致学费,加币,如49800",
        "room_cost": "填写一年的大致住宿费用,加币,如12000",
        "other_cost": "填写一年的大致生活等其它开支,加币,如12000",
        "other": "填写亲戚- relative,或奖学金-scholarship等",
    },
    "info-wpincanada": {"caq_number": "如果工作是在魁北克的,需要拿到CAQ号码,其他省份不需要"},
    "info-wp": {
        "dual_intent": "双重倾向是你既有申请临时签证的愿望，同时又会考虑申请永久居民。",
        "family_tie": "阐述申请人的家庭关系，说明因此会在临时访问后会返回母国",
        "economic_tie": "阐述申请人的经济方面的，比如物业，产业，投资等关系，说明因此会在临时访问后会返回母国",
        "other_tie": "阐述申请人的其他关系，说明因此会在临时访问后会返回母国",
        "application_description": "简短几个词说明目的，用于submission letter的标题",
    },
    "table-cor": {
        "start_date": " 第一行必须填写当前居住国，如果在非国籍所在国，到期日期需要填写您所持签证的到期日.\n第二行开始只需要填写过去5年,不需要包含国籍所在国的居住"
    },
    "table-military": {
        "service_detail": "你的部队信息： 部门,番号,长官姓名",
        "combat_detail": "参加过的战斗的时间、地点",
        "reason_for_end": "说明结束这段服役经历的原因,比如退役...",
    },
    "table-employment": {
        "duties": "可以用鼠标把这个单元拉大,逐条列出你的所有工作职责,可以在其他编辑器中写好然后复制到这里",
        "noc_code": "这个客户不需要填写,由移民顾问填写",
    },
    "info-lmiacase": {
        "stream_of_lmia": "EE(Express Entry: 5593),HWS(High Wage Stream: 5626),WS(Low Wage Stream: 5627),GTS(Global Talent Stream: 5624, 5625),AC (Academic: 5626),AG (Agriculture: 5519, 5510), CG(CareGiver 5604)"
    },
    "info-lmi": {
        "job_creation_benefit": "如果没有，就不用填任何东西",
        "skill_transfer_benefit": "如果没有，就不用填任何东西",
        "fill_shortage_benefit": "如果没有，就不用填任何东西",
        "other_benefit": "如果没有，就不用填任何东西",
    },
    "info-emp5627": {
        "exemption_rationale": "说明你为什么符合免于CAP的理由。对于Seasonal 270天的豁免,提供估计都高峰时间的开始和结束日期"
    },
    "table-captfw": {
        "employee": "本表格中海外劳工包括：已在职的，已聘但尚未上岗，以及本次lmia中准备招聘的",
        "designated_position": "是否属于些职位: on-farm primary agricultural positions, caregiving positions, highly mobile or truly temporary position, seasonal positions?",
        "pr_support_only_lmia": "本次申请的是否是Pr support only的LMIA?",
        "pr_in_process": " 该Foreign worker拿到了省提名或PR visa, 但是没有登陆。",
    },
}

==> imm-apps-1.3.1.tar.gz: imm-apps-1.3.1/source/comment.py <==
comment = {
    "info-positon": {"how_when_offer": "请说明什么时候以及如何给TFW提供offer的"},
    "info-general": {
        "pt_employee_number": "每周工作时间少于30小时的为兼职",
    },
    "table-eraddress": {"mailing_address": "如果地址跟商业地址相同,请copy商业地址到这里"},
    "table-finance": {"year": "请填写上一年度,以及上上年度2年的财务信息"},
    "table-education": {"is_trade": "是否是技工类别？比如水电工"},
    "info-joboffer": {
        "atypical_schedule_explain": "请说明工作时间是如何安排的",
        "ot_after_hours_unit": "加班工资开始计算的单位,比如,每天超过8小时,那么该单位就是day；如果每周超过40小时,那么单位就是week",
        "ot_ratio": "加班工资是平时工资的倍数,比如1.5",
        "vacation_pay_percentage": "一般是4%,就填写4即可",
        "duties": "详细职责描述,可将excel行拉长。每条职责一行,一般在别的编辑器里面写好copy过来即可。",
        "specific_edu_requirement": "一句话描述对学历、教育程度、相关专业的要求",
    },
    "table-family": {"relationship": "请填写你的: 配偶,子女,母亲,父亲,兄弟姐妹,包括同母异父/同母异父的兄弟姐妹,"},
    "table-marriage": {
        "sp_canada_status": "请选择:Citizen (公民),Visitor(访问者,包括旅游,探亲,商务等),Student(学生),Worker(工人),Other(其他)"
    },
    "info-personal": {
        "last_name": "保持跟护照一致都拼音姓",
        "first_name": "保持跟护照一致都拼音名",
        "uci": "加拿大签证上Unified Client Identity号码",
        "ita_assessed": "这个是加拿大行业培训机构(Industry Training Authority)",
        "english_french": "English(英语) French(法语)Both(两个都会) Neither(两个都不会)",
        "primary_school_years": "如果没有,请填写0",
        "secondary_school_years": "如果没有,请填写0",
        "post_secondary_school_years": "如果没有,请填写0",
        "other_school_years": "如果没有,请填写0",
        "dependant_type": "Type A: 22岁以下的申请人, Type B:22岁以上,但一直在读书的。 Type C:22岁以上但有疾病需要依赖父母的",
    },
    "table-personid": {"expiry_date": "如果没有到期日期,请填写当前日期加上30年的日期"},
    "info-personalassess": {
        "work_experience_brief": "教育背景,工作经历,个人品质,语言能力 用于PNP的雇主信或者LMIA申请回答为什么申请人合格的问题。工作表现评价用于已经在该雇主那里工作的情况,在雇主推荐信中使用。"
    },
    "table-language": {
        "registration_number": "CELPIP叫registration number, IELTS叫 Test report form number, TEF叫Attestation n*, TCF叫N° de l'attestation",
        "pin": "仅仅当考试类型是CELPIP时需要",
        "date": "IELTS: administrator signature date,CELPIP: date of signing,TEF: date of session,TEF: date of session",
        "remark": "如果是实际考试成绩,选择Test Score,如果是估计成绩,选择Estimation",
    },
    "info-marriage": {
        "married_date": "若是single则不需要填写",
        "pre_sp_last_name": "只填写最近一段婚姻",
    },
    "table-phone": {"cellular": "优选手机作为通讯选择。如果有手机,只填写手机即可,如果没有,依次可以选择家庭电话,工作电话"},
    "table-address": {
        "residential_address": "如果地址跟邮件地址相同,请copy邮件地址到这里. 如果国家是加拿大,必须填写省份,而且用缩写,比如： AB, BC"
    },
    "info-trcasein": {
        "doc_number": "学签/工签/VR的右上角黑色的,一般为1个字母+9位数字",
        "original_purpose": "Business-商业,Tourism-旅游,study-学习,work-工作,family visit-家庭访问,或者other-其它",
        "original_other_reason": "若上一行填other则将原因补充在这里",
        "most_recent_entry_date": "如果这是第一次，此处不用填写",
        "most_recent_entry_place": "如果这是第一次，此处不用填写",
        "submission_date": "可以不用填写",
    },
    "info-visa": {
        "name1": "可填写学校或工作单位的名称和地址",
        "relationship1": "比如：如果是学校,就写my school.",
        "name2": "可填写学校或工作单位的名称和地址",
        "relationship2": "比如：如果是学校,就写my school.",
    },
    "info-vrincanada": {
        "name1": "可填写学校或工作单位的名称和地址",
        "relationship1": "比如：如果是学校,就写my school.",
        "name2": "可填写学校或工作单位的名称和地址",
        "relationship2": "比如：如果是学校,就写my school.",
        "other_explain": "如果访问目的填写的是Other,请说明。比如:accompany child studying in Canada",
    },
    "info-sp": {
        "dli": "中小学无需填写,大学参考学校给的offer",
        "tuition_cost": "填写一年的大致学费,加币,如49800",
        "room_cost": "填写一年的大致住宿费用,加币,如12000",
        "other_cost": "填写一年的大致生活等其它开支,加币,如12000",
        "other": "填写亲戚- relative,或奖学金-scholarship等",
    },
    "info-spincanada": {
        "dli": "中小学无需填写,大学参考学校给的offer",
        "tuition_cost": "填写一年的大致学费,加币,如49800",
        "room_cost": "填写一年的大致住宿费用,加币,如12000",
        "other_cost": "填写一年的大致生活等其它开支,加币,如12000",
        "other": "填写亲戚- relative,或奖学金-scholarship等",
    },
    "info-wpincanada": {"caq_number": "如果工作是在魁北克的,需要拿到CAQ号码,其他省份不需要"},
    "info-wp": {
        "dual_intent": "双重倾向是你既有申请临时签证的愿望，同时又会考虑申请永久居民。",
        "family_tie": "阐述申请人的家庭关系，说明因此会在临时访问后会返回母国",
        "economic_tie": "阐述申请人的经济方面的，比如物业，产业，投资等关系，说明因此会在临时访问后会返回母国",
        "other_tie": "阐述申请人的其他关系，说明因此会在临时访问后会返回母国",
        "application_description": "简短几个词说明目的，用于submission letter的标题",
    },
    "table-cor": {
        "start_date": " 第一行必须填写当前居住国，如果在非国籍所在国，到期日期需要填写您所持签证的到期日.\n第二行开始只需要填写过去5年,不需要包含国籍所在国的居住"
    },
    "table-military": {
        "service_detail": "你的部队信息： 部门,番号,长官姓名",
        "combat_detail": "参加过的战斗的时间、地点",
        "reason_for_end": "说明结束这段服役经历的原因,比如退役...",
    },
    "table-employment": {
        "duties": "可以用鼠标把这个单元拉大,逐条列出你的所有工作职责,可以在其他编辑器中写好然后复制到这里",
        "noc_code": "这个客户不需要填写,由移民顾问填写",
    },
    "info-lmiacase": {
        "stream_of_lmia": "EE(Express Entry: 5593),HWS(High Wage Stream: 5626),WS(Low Wage Stream: 5627),GTS(Global Talent Stream: 5624, 5625),AC (Academic: 5626),AG (Agriculture: 5519, 5510), CG(CareGiver 5604)"
    },
    "info-lmi": {
        "job_creation_benefit": "如果没有，就不用填任何东西",
        "skill_transfer_benefit": "如果没有，就不用填任何东西",
        "fill_shortage_benefit": "如果没有，就不用填任何东西",
        "other_benefit": "如果没有，就不用填任何东西",
    },
    "info-emp5627": {
        "exemption_rationale": "说明你为什么符合免于CAP的理由。对于Seasonal 270天的豁免,提供估计都高峰时间的开始和结束日期"
    },
    "table-captfw": {
        "employee": "本表格中海外劳工包括：已在职的，已聘但尚未上岗，以及本次lmia中准备招聘的",
        "designated_position": "是否属于些职位: on-farm primary agricultural positions, caregiving positions, highly mobile or truly temporary position, seasonal positions?",
        "pr_support_only_lmia": "本次申请的是否是Pr support only的LMIA?",
        "pr_in_process": " 该Foreign worker拿到了省提名或PR visa, 但是没有登陆。",
    },
}
